/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.charset;

import java.nio.charset.Charset;
import java.nio.charset.CharsetDecoder;
import java.nio.charset.CharsetEncoder;

/**
 * {@link StartsWithCharset} - A charset that delegates an unknown charset name to a supported charset whose name starts with unknown name.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class StartsWithCharset extends Charset {

    private final Charset delegate;

    /**
     * Initializes a new starts-with charset.
     *
     * @param canonicalName The canonical name of the starts-with charset
     * @param delegate The delegate charset
     */
    public StartsWithCharset(final String canonicalName, final Charset delegate) {
        super(canonicalName, null);
        this.delegate = delegate;
    }

    @Override
    public boolean contains(final Charset cs) {
        return this.getClass().isInstance(cs) || delegate.contains(cs);
    }

    @Override
    public boolean canEncode() {
        return delegate.canEncode();
    }

    @Override
    public CharsetDecoder newDecoder() {
        return delegate.newDecoder();
    }

    @Override
    public CharsetEncoder newEncoder() {
        return delegate.newEncoder();
    }

}
