/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.mail.json.compose.share;

import java.util.Date;
import java.util.Locale;
import com.openexchange.exception.OXException;
import com.openexchange.mail.json.compose.ComposeRequest;

/**
 * {@link ShareComposeTemplateLoader}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.2
 */
public interface ShareComposeTemplateLoader {

    /**
     * Loads the message text's prefix from template
     *
     * @param locale The locale
     * @param link The link
     * @param password The optional password
     * @param elapsedDate The optional expiration date
     * @param composeRequest The associated compose request
     * @return The loaded prefix
     * @throws OXException If prefix cannot be loaded
     */
    String loadPrefixFromTemplate(Locale locale, ShareComposeLink link, String password, Date elapsedDate, ComposeRequest composeRequest) throws OXException;
}
